// file_comp.h
// $Id: file_comp.h,v 1.1.1.1 2007/09/19 05:49:54 sendan Exp $
// masashi shimakura

#ifndef _FILE_COMP_
  #define _FILE_COMP_

// ディレクトリの強制値の指定を使う
  #define COMPUL_PATH "/usr/local/zither/sample_bin"

  #define VER_INFO "libfile_comp-1.0.1"
  #define DEFAULT_PATH "/usr/local/zither/sample_bin"
  #define DEFAULT_NAME "zihter_test.txt"
  #define DEFAULT_USER "root"
  #define DEFAULT_GROUP "wheel"
  #define DEFAULT_PERM "0644"

  #define MAX_BUFF (1024 * 1024)
  #define MIN_BUFF 64
  #define IP_BUFF 128

  // ライブラリーでOFF
//  #define LIBFILE_COMP_BUG

  typedef struct comp_private_data private_data_comp;

  struct comp_private_data{
     char ** val_data;
     unsigned char * val_attr;
     struct { 
        char * comment;
        char * command_path;
        char * command_name;
        char * user;
        char * group;
        char * permission;
        } head_buff;
     };


   int file_comp(char * chB, char * comp_path);
   int comp_private_malloc_set(private_data_comp *, int);
   int comp_private_malloc_free(private_data_comp *, int);
   int conf_seting(private_data_comp *, char *);


# endif


